@@ -1,5 +1,5 @@
 from pkg_resources import get_distribution, DistributionNotFound
-from executor_dkr._impl import DockerResource, build, run  # noqa: F401
+from executor_dkr._impl import DockerResource, run  # noqa: F401
 try:
     __version__ = get_distribution("executor-dkr").version
 except DistributionNotFound:
